You are viewing a plain text version of this content. The canonical link for it is here.
Posted to jdo-commits@db.apache.org by cl...@apache.org on 2005/12/28 07:51:20 UTC

svn commit: r359422 - in /db/jdo/trunk: api20/src/java/javax/jdo/PersistenceManager.java tck20/test/java/org/apache/jdo/tck/api/instancecallbacks/InstanceLifecycleListenerAttach.java

Author: clr
Date: Tue Dec 27 22:51:18 2005
New Revision: 359422

URL: http://svn.apache.org/viewcvs?rev=359422&view=rev
Log:
JDO-257 removed attachCopy and attachCopyAll methods; left comments to be removed later

Modified:
    db/jdo/trunk/api20/src/java/javax/jdo/PersistenceManager.java
    db/jdo/trunk/tck20/test/java/org/apache/jdo/tck/api/instancecallbacks/InstanceLifecycleListenerAttach.java

Modified: db/jdo/trunk/api20/src/java/javax/jdo/PersistenceManager.java
URL: http://svn.apache.org/viewcvs/db/jdo/trunk/api20/src/java/javax/jdo/PersistenceManager.java?rev=359422&r1=359421&r2=359422&view=diff
==============================================================================
--- db/jdo/trunk/api20/src/java/javax/jdo/PersistenceManager.java (original)
+++ db/jdo/trunk/api20/src/java/javax/jdo/PersistenceManager.java Tue Dec 27 22:51:18 2005
@@ -837,8 +837,9 @@
      * @return the re-attached instance
      * @see #attachCopyAll(Object[],boolean)
      * @since		2.0
+     * This method has been removed. See makePersistent.
      */
-    Object attachCopy (Object pc, boolean makeTransactional);
+//    Object attachCopy (Object pc, boolean makeTransactional);
 
     /**
      * Import the specified objects into the
@@ -850,8 +851,9 @@
      * @return the re-attached instances
      * @see #attachCopyAll(Object[],boolean)
      * @since 2.0
+     * This method has been removed. See makePersistentAll.
      */
-    Collection attachCopyAll (Collection pcs, boolean makeTransactional);
+ //   Collection attachCopyAll (Collection pcs, boolean makeTransactional);
 
     /**
      * Import the specified objects into the
@@ -867,8 +869,9 @@
      * @return the re-attached instances
      * @see #detachCopyAll(Object[])
      * @since 2.0
+     * This method has been removed. See makePersistentAll.
      */
-    Object[] attachCopyAll (Object[] pcs, boolean makeTransactional);
+  //  Object[] attachCopyAll (Object[] pcs, boolean makeTransactional);
 
     /**
      * Put the specified key-value pair into the map of user objects.

Modified: db/jdo/trunk/tck20/test/java/org/apache/jdo/tck/api/instancecallbacks/InstanceLifecycleListenerAttach.java
URL: http://svn.apache.org/viewcvs/db/jdo/trunk/tck20/test/java/org/apache/jdo/tck/api/instancecallbacks/InstanceLifecycleListenerAttach.java?rev=359422&r1=359421&r2=359422&view=diff
==============================================================================
--- db/jdo/trunk/tck20/test/java/org/apache/jdo/tck/api/instancecallbacks/InstanceLifecycleListenerAttach.java (original)
+++ db/jdo/trunk/tck20/test/java/org/apache/jdo/tck/api/instancecallbacks/InstanceLifecycleListenerAttach.java Tue Dec 27 22:51:18 2005
@@ -104,8 +104,8 @@
         pm.currentTransaction().commit();
         pm.currentTransaction().begin();
         listener.setExpectedSource(detached);
-        // attachCopy should cause the attach listeners to be called
-        PC attached = (PC)pm.attachCopy(detached, false);
+        // makePersistent should cause the attach listeners to be called
+        PC attached = (PC)pm.makePersistent(detached);
         pm.currentTransaction().commit();
 
         // now check the callback and listener were called